@@ -252,7 +252,6 @@ class PhabricatorAPI(object):
         )
 
         def _clean(diff):
-
             # Make all fields easily accessible
             if "fields" in diff and isinstance(diff["fields"], dict):
                 diff.update(diff["fields"])
@@ -301,6 +300,16 @@ class PhabricatorAPI(object):
             raise PhabricatorRevisionNotFoundException()
         return data[0]
 
+    def edit_revision(self, revision_id, transactions):
+        """
+        Edit a differential revision
+        """
+        return self.request(
+            "differential.revision.edit",
+            objectIdentifier=revision_id,
+            transactions=transactions,
+        )
+
     def list_repositories(self):
         """
         List available repositories
@@ -489,7 +498,7 @@ class PhabricatorAPI(object):
         assert isinstance(state, BuildState)
         return self.request(
             "harbormaster.sendmessage",
-            buildTargetPHID=build_target_phid,
+            receiver=build_target_phid,
             type=state.value,
             unit=unit,
             lint=lint,
@@ -672,6 +681,7 @@ class PhabricatorAPI(object):
         without hitting a local mercurial repository
         If the full diff details are provided, they can be used directly in the stack
         """
+
         # Diff PHIDs from our patch to its base
         def add_patch(diff):
             # Build a nicer Diff instance with associated commit & patch
@@ -704,7 +714,6 @@ class PhabricatorAPI(object):
 
         parents = self.load_parents(diff["revisionPHID"])
         if parents:
-
             # Load all parent diffs
             for parent in parents:
                 logger.info("Loading parent diff {}".format(parent))
